@@ -18,21 +18,21 @@
 
 #include "xcbeventlistener.h"
 
-#include <QX11Info>
 #include <QGuiApplication>
+#include <QX11Info>
 
 #include <QRect>
 
 Q_LOGGING_CATEGORY(KSCREEN_XCB_HELPER, "kscreen.xcb.helper")
 
-XCBEventListener::XCBEventListener():
-    m_isRandrPresent(false),
-    m_randrBase(0),
-    m_randrErrorBase(0),
-    m_majorOpcode(0),
-    m_versionMajor(0),
-    m_versionMinor(0),
-    m_window(0)
+XCBEventListener::XCBEventListener()
+    : m_isRandrPresent(false)
+    , m_randrBase(0)
+    , m_randrErrorBase(0)
+    , m_majorOpcode(0)
+    , m_versionMajor(0)
+    , m_versionMinor(0)
+    , m_window(0)
 {
     xcb_connection_t *c = QX11Info::connection();
     xcb_prefetch_extension_data(c, &xcb_randr_id);
@@ -64,21 +64,16 @@ XCBEventListener::XCBEventListener():
 
     qCDebug(KSCREEN_XCB_HELPER).nospace() << "Detected XRandR " << m_versionMajor << "." << m_versionMinor;
     qCDebug(KSCREEN_XCB_HELPER) << "Event Base: " << m_randrBase;
-    qCDebug(KSCREEN_XCB_HELPER) << "Event Error: "<< m_randrErrorBase;
+    qCDebug(KSCREEN_XCB_HELPER) << "Event Error: " << m_randrErrorBase;
 
     uint32_t rWindow = QX11Info::appRootWindow();
     m_window = xcb_generate_id(c);
-    xcb_create_window(c, XCB_COPY_FROM_PARENT, m_window,
-                      rWindow,
-                      0, 0, 1, 1, 0, XCB_COPY_FROM_PARENT,
-                      XCB_COPY_FROM_PARENT, 0, nullptr);
+    xcb_create_window(c, XCB_COPY_FROM_PARENT, m_window, rWindow, 0, 0, 1, 1, 0, XCB_COPY_FROM_PARENT, XCB_COPY_FROM_PARENT, 0, nullptr);
 
-    xcb_randr_select_input(c, m_window,
-            XCB_RANDR_NOTIFY_MASK_SCREEN_CHANGE |
-            XCB_RANDR_NOTIFY_MASK_OUTPUT_CHANGE |
-            XCB_RANDR_NOTIFY_MASK_CRTC_CHANGE |
-            XCB_RANDR_NOTIFY_MASK_OUTPUT_PROPERTY
-    );
+    xcb_randr_select_input(c,
+                           m_window,
+                           XCB_RANDR_NOTIFY_MASK_SCREEN_CHANGE | XCB_RANDR_NOTIFY_MASK_OUTPUT_CHANGE | XCB_RANDR_NOTIFY_MASK_CRTC_CHANGE
+                               | XCB_RANDR_NOTIFY_MASK_OUTPUT_PROPERTY);
 
     qApp->installNativeEventFilter(this);
 }
@@ -124,7 +119,7 @@ QString XCBEventListener::connectionToString(xcb_randr_connection_t connection)
     return QStringLiteral("invalid value (%1)").arg(connection);
 }
 
-bool XCBEventListener::nativeEventFilter(const QByteArray& eventType, void* message, long int* result)
+bool XCBEventListener::nativeEventFilter(const QByteArray &eventType, void *message, long int *result)
 {
     Q_UNUSED(result);
 
@@ -135,7 +130,7 @@ bool XCBEventListener::nativeEventFilter(const QByteArray& eventType, void* mess
     auto *e = static_cast<xcb_generic_event_t *>(message);
     const uint8_t xEventType = e->response_type & ~0x80;
 
-    //If this event is not xcb_randr_notify, we don't want it
+    // If this event is not xcb_randr_notify, we don't want it
     if (xEventType == m_randrBase + XCB_RANDR_SCREEN_CHANGE_NOTIFY) {
         handleScreenChange(e);
     }
@@ -146,9 +141,9 @@ bool XCBEventListener::nativeEventFilter(const QByteArray& eventType, void* mess
     return false;
 }
 
-void XCBEventListener::handleScreenChange(xcb_generic_event_t* e)
+void XCBEventListener::handleScreenChange(xcb_generic_event_t *e)
 {
-    auto *e2 = reinterpret_cast<xcb_randr_screen_change_notify_event_t*>(e);
+    auto *e2 = reinterpret_cast<xcb_randr_screen_change_notify_event_t *>(e);
 
     // Only accept notifications for our window
     if (e2->request_window != m_window) {
@@ -158,46 +153,44 @@ void XCBEventListener::handleScreenChange(xcb_generic_event_t* e)
     qCDebug(KSCREEN_XCB_HELPER) << "RRScreenChangeNotify";
     qCDebug(KSCREEN_XCB_HELPER) << "\tWindow:" << e2->request_window;
     qCDebug(KSCREEN_XCB_HELPER) << "\tRoot:" << e2->root;
-    qCDebug(KSCREEN_XCB_HELPER) << "\tRotation: " << rotationToString((xcb_randr_rotation_t) e2->rotation);
+    qCDebug(KSCREEN_XCB_HELPER) << "\tRotation: " << rotationToString((xcb_randr_rotation_t)e2->rotation);
     qCDebug(KSCREEN_XCB_HELPER) << "\tSize ID:" << e2->sizeID;
     qCDebug(KSCREEN_XCB_HELPER) << "\tSize: " << e2->width << e2->height;
     qCDebug(KSCREEN_XCB_HELPER) << "\tSizeMM: " << e2->mwidth << e2->mheight;
 
-    Q_EMIT screenChanged((xcb_randr_rotation_t) e2->rotation, QSize(e2->width, e2->height), QSize(e2->mwidth, e2->mheight));
+    Q_EMIT screenChanged((xcb_randr_rotation_t)e2->rotation, QSize(e2->width, e2->height), QSize(e2->mwidth, e2->mheight));
     Q_EMIT outputsChanged();
 }
 
-void XCBEventListener::handleXRandRNotify(xcb_generic_event_t* e)
+void XCBEventListener::handleXRandRNotify(xcb_generic_event_t *e)
 {
-    auto *randrEvent = reinterpret_cast<xcb_randr_notify_event_t*>(e);
+    auto *randrEvent = reinterpret_cast<xcb_randr_notify_event_t *>(e);
 
     if (randrEvent->subCode == XCB_RANDR_NOTIFY_CRTC_CHANGE) {
         xcb_randr_crtc_change_t crtc = randrEvent->u.cc;
         qCDebug(KSCREEN_XCB_HELPER) << "RRNotify_CrtcChange";
         qCDebug(KSCREEN_XCB_HELPER) << "\tCRTC: " << crtc.crtc;
         qCDebug(KSCREEN_XCB_HELPER) << "\tMode: " << crtc.mode;
-        qCDebug(KSCREEN_XCB_HELPER) << "\tRotation: " << rotationToString((xcb_randr_rotation_t) crtc.rotation);
+        qCDebug(KSCREEN_XCB_HELPER) << "\tRotation: " << rotationToString((xcb_randr_rotation_t)crtc.rotation);
         qCDebug(KSCREEN_XCB_HELPER) << "\tGeometry: " << crtc.x << crtc.y << crtc.width << crtc.height;
-        Q_EMIT crtcChanged(crtc.crtc, crtc.mode, (xcb_randr_rotation_t) crtc.rotation,
-                           QRect(crtc.x, crtc.y, crtc.width, crtc.height));
+        Q_EMIT crtcChanged(crtc.crtc, crtc.mode, (xcb_randr_rotation_t)crtc.rotation, QRect(crtc.x, crtc.y, crtc.width, crtc.height));
 
-    } else if(randrEvent->subCode == XCB_RANDR_NOTIFY_OUTPUT_CHANGE) {
+    } else if (randrEvent->subCode == XCB_RANDR_NOTIFY_OUTPUT_CHANGE) {
         xcb_randr_output_change_t output = randrEvent->u.oc;
         qCDebug(KSCREEN_XCB_HELPER) << "RRNotify_OutputChange";
         qCDebug(KSCREEN_XCB_HELPER) << "\tOutput: " << output.output;
         qCDebug(KSCREEN_XCB_HELPER) << "\tCRTC: " << output.crtc;
         qCDebug(KSCREEN_XCB_HELPER) << "\tMode: " << output.mode;
-        qCDebug(KSCREEN_XCB_HELPER) << "\tRotation: " << rotationToString((xcb_randr_rotation_t) output.rotation);
-        qCDebug(KSCREEN_XCB_HELPER) << "\tConnection: " << connectionToString((xcb_randr_connection_t) output.connection);
+        qCDebug(KSCREEN_XCB_HELPER) << "\tRotation: " << rotationToString((xcb_randr_rotation_t)output.rotation);
+        qCDebug(KSCREEN_XCB_HELPER) << "\tConnection: " << connectionToString((xcb_randr_connection_t)output.connection);
         qCDebug(KSCREEN_XCB_HELPER) << "\tSubpixel Order: " << output.subpixel_order;
-        Q_EMIT outputChanged(output.output, output.crtc, output.mode,
-                             (xcb_randr_connection_t) output.connection);
+        Q_EMIT outputChanged(output.output, output.crtc, output.mode, (xcb_randr_connection_t)output.connection);
 
-    } else if(randrEvent->subCode == XCB_RANDR_NOTIFY_OUTPUT_PROPERTY) {
+    } else if (randrEvent->subCode == XCB_RANDR_NOTIFY_OUTPUT_PROPERTY) {
         xcb_randr_output_property_t property = randrEvent->u.op;
 
-        XCB::ScopedPointer<xcb_get_atom_name_reply_t> reply(xcb_get_atom_name_reply(QX11Info::connection(),
-                xcb_get_atom_name(QX11Info::connection(), property.atom), nullptr));
+        XCB::ScopedPointer<xcb_get_atom_name_reply_t> reply(
+            xcb_get_atom_name_reply(QX11Info::connection(), xcb_get_atom_name(QX11Info::connection(), property.atom), nullptr));
 
         qCDebug(KSCREEN_XCB_HELPER) << "RRNotify_OutputProperty (ignored)";
         qCDebug(KSCREEN_XCB_HELPER) << "\tOutput: " << property.output;
